==> websvn-2.3.3-7-any.pkg.tar.xz: srv/http/websvn/languages/french.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Erik Le Blanc
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// french.php
//
// French language strings
// Translated by Yokav (mailme@yokav.info)

$lang["LANGUAGETAG"] = "fr"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "French";
$lang["LANGUAGENAMENATIVE"] = "Français";
$lang["LANGUAGENAMEHTML"] = "Fran&ccedil;ais";

$lang["LOG"] = "Journal";
$lang["DIFF"] = "Diffé.";

$lang["NOREP"] = "Pas de dépôt fourni.";
$lang["NOPATH"] = "Répertoire non trouvé.";
$lang["NOACCESS"] = "Vous n'avez pas la permission nécessaire pour accéder à ce répertoire.";
$lang["RESTRICTED"] = "Accès restreint.";
$lang["SUPPLYREP"] = "Veuillez indiquer le répertoire d'un dépôt dans le fichier include/config.php en utilisant <code>\$config->parentPath</code> ou <code>\$config->addRepository</code>. Lisez le guide d'installation pour plus de détails.";

$lang["DIFFREVS"] = "Différences entre les révisions";
$lang["AND"] = "et";
$lang["REV"] = "Révision";
$lang["LINE"] = "Ligne";
$lang["LINENO"] = "Ligne Num.";
$lang["SHOWENTIREFILE"] = "Afficher tout le fichier";
$lang["SHOWCOMPACT"] = "Afficher seulement les passages avec des différences";
$lang["IGNOREWHITESPACE"] = "Ignorer les espaces blanc";
$lang["REGARDWHITESPACE"] = "Prendre en compte les espaces blanc";

$lang["LISTING"] = "Arborescence";
$lang["FILEDETAIL"] = "Détails";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Différence avec la précédente";
$lang["BLAME"] = "Responsabilité";
$lang["BLAMEFOR"] = "Information sur la responsabilité de la rev";

$lang["REVINFO"] = "Information sur la Révision";
$lang["GOYOUNGEST"] = "Aller à la révision la plus récente";
$lang["LASTMOD"] = "Dernière modification";
$lang["LOGMSG"] = "Message du journal";
$lang["CHANGES"] = "Changements";
$lang["SHOWCHANGED"] = "Montrer les fichiers modifiés";
$lang["HIDECHANGED"] = "Cacher les fichiers modifiés";
$lang["NEWFILES"] = "Nouveaux fichiers";
$lang["CHANGEDFILES"] = "Fichiers modifiés";
$lang["DELETEDFILES"] = "Fichiers supprimés";
$lang["VIEWLOG"] = "Afficher le Journal";
$lang["PATH"] = "Chemin";
$lang["AUTHOR"] = "Auteur";
$lang["AGE"] = "Ancienneté";
$lang["CURDIR"] = "Répertoire courant";
$lang["TARBALL"] = "Tarball";
$lang["DOWNLOAD"] = "Télécharger";

$lang["PREV"] = "Précédent";
$lang["NEXT"] = "Suivant";
$lang["SHOWALL"] = "Tout montrer";

$lang["BADCMD"] = "Cette commande a provoqué une erreur";
$lang["UNKNOWNREVISION"] = "Révision non trouvée";

$lang["POWERED"] = "Propulsé par <a href=\"http://www.websvn.info/\">WebSVN</a>";
$lang["PROJECTS"] = "Dépôts Subversion";
$lang["SERVER"] = "Serveur Subversion";

$lang["FILTER"] = "Options de recherche";
$lang["STARTLOG"] = "De la rév.";
$lang["ENDLOG"] = "A la rév.";
$lang["MAXLOG"] = "Max révs.";
$lang["SEARCHLOG"] = "Rechercher dans le journal";
$lang["CLEARLOG"] = "Effacer la recherche courante";
$lang["MORERESULTS"] = "Trouver plus de réponses...";
$lang["NORESULTS"] = "Il n'y a pas de réponse à votre recherche dans le journal";
$lang["NOMORERESULTS"] = "Il n'y a pas plus de réponses à votre recherche";
$lang["NOPREVREV"] = "Pas de révision antérieur";

$lang["RSSFEEDTITLE"] = "Flux RSS de WebSVN";
$lang["FILESMODIFIED"] = "fichier(s) modifié(s)";
$lang["RSSFEED"] = "Flux RSS";

$lang["DAYLETTER"] = "j";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Go";

$lang["PATHCOMPARISON"] = "Comparaison de dossiers";
$lang["COMPAREPATHS"] = "Comparer les dossiers";
$lang["COMPAREREVS"] = "Comparer les révisions";
$lang["PROPCHANGES"] = "Changements de propriété:";
$lang["CONVFROM"] = "Cette comparaison affiche les changements nécessaires pour convertir le dossier ";
$lang["TO"] = "EN";
$lang["REVCOMP"] = "Comparaison inverse";
$lang["COMPPATH"] = "Comparer le dossier:";
$lang["WITHPATH"] = "Au dossier:";
$lang["FILEDELETED"] = "Fichier supprimé";
$lang["FILEADDED"] = "Nouveau fichier";

==> websvn-2.5-1-any.pkg.tar.xz: srv/http/websvn/languages/french.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Erik Le Blanc
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// french.php
//
// French language strings
// Translated by Yokav (mailme@yokav.info)

$lang["LANGUAGETAG"] = "fr"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "French";
$lang["LANGUAGENAMENATIVE"] = "Français";
$lang["LANGUAGENAMEHTML"] = "Fran&ccedil;ais";

$lang["LOG"] = "Journal";
$lang["DIFF"] = "Diffé.";

$lang["NOREP"] = "Pas de dépôt fourni.";
$lang["NOPATH"] = "Répertoire non trouvé.";
$lang["NOACCESS"] = "Vous n'avez pas la permission nécessaire pour accéder à ce répertoire.";
$lang["RESTRICTED"] = "Accès restreint.";
$lang["SUPPLYREP"] = "Veuillez indiquer le répertoire d'un dépôt dans le fichier include/config.php en utilisant <code>\$config->parentPath</code> ou <code>\$config->addRepository</code>. Lisez le guide d'installation pour plus de détails.";

$lang["DIFFREVS"] = "Différences entre les révisions";
$lang["AND"] = "et";
$lang["REV"] = "Révision";
$lang["LINE"] = "Ligne";
$lang["LINENO"] = "Ligne Num.";
$lang["SHOWENTIREFILE"] = "Afficher tout le fichier";
$lang["SHOWCOMPACT"] = "Afficher seulement les passages avec des différences";
$lang["IGNOREWHITESPACE"] = "Ignorer les espaces blanc";
$lang["REGARDWHITESPACE"] = "Prendre en compte les espaces blanc";

$lang["LISTING"] = "Arborescence";
$lang["FILEDETAIL"] = "Détails";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Différence avec la précédente";
$lang["BLAME"] = "Responsabilité";
$lang["BLAMEFOR"] = "Information sur la responsabilité de la rev";

$lang["REVINFO"] = "Information sur la Révision";
$lang["GOYOUNGEST"] = "Aller à la révision la plus récente";
$lang["LASTMOD"] = "Dernière modification";
$lang["LOGMSG"] = "Message du journal";
$lang["CHANGES"] = "Changements";
$lang["SHOWCHANGED"] = "Montrer les fichiers modifiés";
$lang["HIDECHANGED"] = "Cacher les fichiers modifiés";
$lang["NEWFILES"] = "Nouveaux fichiers";
$lang["CHANGEDFILES"] = "Fichiers modifiés";
$lang["DELETEDFILES"] = "Fichiers supprimés";
$lang["VIEWLOG"] = "Afficher le Journal";
$lang["PATH"] = "Chemin";
$lang["AUTHOR"] = "Auteur";
$lang["AGE"] = "Ancienneté";
$lang["CURDIR"] = "Répertoire courant";
$lang["TARBALL"] = "Tarball";
$lang["DOWNLOAD"] = "Télécharger";

$lang["PREV"] = "Précédent";
$lang["NEXT"] = "Suivant";
$lang["SHOWALL"] = "Tout montrer";

$lang["BADCMD"] = "Cette commande a provoqué une erreur";
$lang["UNKNOWNREVISION"] = "Révision non trouvée";

$lang["POWERED"] = "Propulsé par <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Dépôts Subversion";
$lang["SERVER"] = "Serveur Subversion";

$lang["FILTER"] = "Options de recherche";
$lang["STARTLOG"] = "De la rév.";
$lang["ENDLOG"] = "A la rév.";
$lang["MAXLOG"] = "Max révs.";
$lang["SEARCHLOG"] = "Rechercher dans le journal";
$lang["CLEARLOG"] = "Effacer la recherche courante";
$lang["MORERESULTS"] = "Trouver plus de réponses...";
$lang["NORESULTS"] = "Il n'y a pas de réponse à votre recherche dans le journal";
$lang["NOMORERESULTS"] = "Il n'y a pas plus de réponses à votre recherche";
$lang["NOPREVREV"] = "Pas de révision antérieur";

$lang["RSSFEEDTITLE"] = "Flux RSS de WebSVN";
$lang["FILESMODIFIED"] = "fichier(s) modifié(s)";
$lang["RSSFEED"] = "Flux RSS";

$lang["DAYLETTER"] = "j";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Go";

$lang["PATHCOMPARISON"] = "Comparaison de dossiers";
$lang["COMPAREPATHS"] = "Comparer les dossiers";
$lang["COMPAREREVS"] = "Comparer les révisions";
$lang["PROPCHANGES"] = "Changements de propriété:";
$lang["CONVFROM"] = "Cette comparaison affiche les changements nécessaires pour convertir le dossier ";
$lang["TO"] = "EN";
$lang["REVCOMP"] = "Comparaison inverse";
$lang["COMPPATH"] = "Comparer le dossier:";
$lang["WITHPATH"] = "Au dossier:";
$lang["FILEDELETED"] = "Fichier supprimé";
$lang["FILEADDED"] = "Nouveau fichier";
